local AddOn, NS = ...
local gsub, lower, upper = string.gsub, string.lower, string.upper

local classesIcons = CLASS_ICON_TCOORDS

function NS:DUF_Set_ClassIcon(unit)
	if FIZZLEDEBUG and not DUF_FRAME_DATA[unit] then
		FIZZLEDEBUG("DUF_Set_ClassIcon: bad unit", unit)
		return
	end
	local texture = _G[DUF_FRAME_DATA[unit].frame.."_ClassIcon"].Icon
	local class, file = UnitClass(unit);
	if not file then return end
	local left, right, top, bottom = unpack(classesIcons[file])
	if (class) then
		texture:SetTexCoord(right, left, top, bottom);	
	else
		texture:SetTexCoord(0, .25, 0, .25);
	end
	if (DUF_Settings[DUF_INDEX][DUF_FRAME_DATA[unit].index].ClassIcon.userace) then
		if (UnitIsPlayer(unit)) then
--			texture:SetTexture("Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes");
			texture:SetTexture("Interface\\WorldStateFrame\\Icons-Classes")
		else
			NS:DUF_Set_RaceIcon(unit, true, texture);
		end
	else
			texture:SetTexture("Interface\\WorldStateFrame\\Icons-Classes")
	end
end

--[[
function NS:DUF_Set_ClassIcon(unit)
	if FIZZLEDEBUG and not DUF_FRAME_DATA[unit] then
		FIZZLEDEBUG("DUF_Set_ClassIcon: bad unit", unit)
		return
	end
	local texture = _G[DUF_FRAME_DATA[unit].frame.."_ClassIcon"].Icon
	local class, file = UnitClass(unit)
	if not file then 
		if not DUF_OPTIONS_VISIBLE then
			return 
		else
			class, file = UnitClass("player")
		end
	end
	file = gsub(lower(file), " ", "")
	local Atlas = "classicon-"..file
	texture:SetAtlas(Atlas, true)
	if (DUF_Settings[DUF_INDEX][DUF_FRAME_DATA[unit].index].ClassIcon.userace) then
		if (UnitIsPlayer(unit)) then
			texture:SetTexture("Interface\\TargetingFrame\\UI-Classes-Circles")
		else
			NS:DUF_Set_RaceIcon(unit, 1, texture)
		end
	end
end
]]--

function NS:DUF_Set_ElementPosition(frame, unitFrame, settings)
	local attachframe = unitFrame..settings.attach
	if (settings.attach == "Unit Frame") then
		attachframe = unitFrame
	elseif (settings.attach == "UIParent") then
		attachframe = "UIParent"
	end
	frame:ClearAllPoints()
	local attached = select(2, _G[attachframe]:GetPoint(1))
	if attached == frame then -- OLD (currently in use like ["Default"]) setting has attachframe SetPointed to THIS frame we should clear it 
		_G[attachframe]:ClearAllPoints() -- (Unless there's a bug in the Saved Variables this should clear up when the attachframe is configured later)
	end
	frame:SetPoint(settings.attachpoint, attachframe, settings.attachto, settings.xoffset, settings.yoffset)
end

function NS:DUF_Set_EliteTexture()
	local texture
  	local ELITE_SETTINGS = DUF_Settings[DUF_INDEX].target.EliteTexture
	if (ELITE_SETTINGS.elitetexture and ELITE_SETTINGS.elitetexture ~= "") then
		texture = NS:GetResourcePath(ELITE_SETTINGS.elitetexture)
	elseif (ELITE_SETTINGS.faceleft) then
		texture = "Interface/AddOns/DiscordUnitFrames/Icons/EliteLeft"
	else
		texture = "Interface/AddOns/DiscordUnitFrames/Icons/Elite"
	end
	if (DUF_OPTIONS_VISIBLE and (not ELITE_SETTINGS.hide)) then
		DUF_TargetFrame_EliteTexture_Texture:SetTexture(texture)
		DUF_TargetFrame_EliteTexture:Show()
		DUF_TargetFrame_EliteTexture:SetAlpha(ELITE_SETTINGS.alpha)
		return
	end
	local classification = UnitClassification("target")
	if (classification == "elite" or classification == "worldboss") then
		if (not ELITE_SETTINGS.hide) then
			DUF_TargetFrame_EliteTexture_Texture:SetTexture(texture)
			DUF_TargetFrame_EliteTexture:SetAlpha(ELITE_SETTINGS.alpha)
		end
	elseif (classification == "rare" or classification == "rareelite") then
		if (not ELITE_SETTINGS.hide) then
			if (ELITE_SETTINGS.raretexture and ELITE_SETTINGS.raretexture ~= "") then
				texture = NS:GetResourcePath(ELITE_SETTINGS.raretexture)
			elseif (ELITE_SETTINGS.faceleft) then
				texture = "Interface/AddOns/DiscordUnitFrames/Icons/RareLeft"
			else
				texture = "Interface/AddOns/DiscordUnitFrames/Icons/Rare"
			end
			DUF_TargetFrame_EliteTexture_Texture:SetTexture(texture)
			DUF_TargetFrame_EliteTexture:SetAlpha(ELITE_SETTINGS.alpha)
		end
	else
		DUF_TargetFrame_EliteTexture:SetAlpha(0)
	end
	local icon = DUF_TargetFrame_QuestBossIcon
	if not DUF_OPTIONS_VISIBLE and not icon.questbossiconhide then 
		if NS.UnitIsQuestBoss("target") then
			icon:SetAlpha(1)
		else
			icon:SetAlpha(0)
		end
	end
end

function NS:DUF_Set_Portrait(unit)
	if FIZZLEDEBUG and not DUF_FRAME_DATA[unit] then
		FIZZLEDEBUG("DUF_Set_Portrait: bad unit", unit)
		return
	end
	local frame = _G[DUF_FRAME_DATA[unit].frame .. "_Portrait"]
	if not frame then return end
	if (not frame:IsVisible()) then return end
	local use3D, use3Dface = NS:DUF_Get3D(unit)
	if (use3D) then
		if FIZZLEDEBUG and not frame.Model then
			FIZZLEDEBUG("DUF_Set_Portrait", unit, frame:GetName())
		end
		frame.Model.seqtime = 0
		frame:SetAlpha(1)
		frame.Model:SetUnit(unit)
		if (DUF_OPTIONS_VISIBLE) then
			frame:SetBackdrop({bgFile = "Interface/Tooltips/UI-Tooltip-Background", edgeFile = ""})
			frame:SetBackdropColor(0,0,1,0.5)
			if (not UnitExists(unit) or (UnitExists(unit) and not UnitIsVisible(unit))) then
				frame.Model:SetUnit('player')
			end
		else
			frame:SetBackdrop(nil)
			frame:SetBackdropColor(0, 0, 0 , 0)
		end
		frame.Model:SetPosition(0, 0, 0)
		if (use3Dface) then
			--SetCamera(1)
			frame.Model:SetPortraitZoom(1)
			if (DUF_Settings[DUF_INDEX][DUF_FRAME_DATA[unit].index].Portrait.flip) then
				frame.Model:SetPosition(0, 0.1, 0)
				frame.Model:SetFacing(-1.2)
			else
				frame.Model:SetPosition(0, 0, 0)
				frame.Model:SetFacing(0)
			end
		else
			--frame:SetCamera(0)
			frame.Model:SetPortraitZoom(0)
		end
		return
	else   
		local texture = _G[DUF_FRAME_DATA[unit].frame.."_Portrait"].Portrait
		texture:SetTexCoord(0, 1, 0, 1)
		if (UnitName(unit)) then
			SetPortraitTexture(texture, unit)
		else
			SetPortraitTexture(texture, "player")
		end
		if (DUF_Settings[DUF_INDEX][DUF_FRAME_DATA[unit].index].Portrait.useclass and UnitIsPlayer(unit)) then
			local class, file = UnitClass(unit)
			local left, right, top, bottom = unpack(classesIcons[file])
			if (class) then
--				texture:SetTexture("Interface\\Glues\\CharacterCreate\\UI-CharacterCreate-Classes")
				texture:SetTexture("Interface\\WorldStateFrame\\Icons-Classes")
				texture:SetTexCoord(right, left, top, bottom)	
			end
		end
		if (DUF_Settings[DUF_INDEX][DUF_FRAME_DATA[unit].index].Portrait.flip) then
			local ULx, ULy, LLx, LLy, URx, URy, LRx, LRy = texture:GetTexCoord()
			texture:SetTexCoord(URx, ULy, LRx, LLy, ULx, URy, LLx, LRy)	
		end
	end
end
-- Copied from GLUE. For table below see Blizzarfd SharedXML Util.lua or SharedConstants.lua
local fixedRaceAtlasNames = {
	["highmountaintauren"] = "highmountain",
	["lightforgeddraenei"] = "lightforged",
	["scourge"] = "undead",
	["zandalaritroll"] = "zandalari",
}

function NS:DUF_Set_RaceIcon(unit, toggle, texture)
	local race = select(2, UnitRace(unit)) -- get the file name
	local sex = UnitSex(unit)
	local ctype = UnitCreatureType(unit)
	local faction = UnitFactionGroup(unit)
	if not texture then
		if FIZZLEDEBUG and not DUF_FRAME_DATA[unit] then
			FIZZLEDEBUG("DUF_Set_RaceIcon: bad unit", unit)
			return
		end
		texture = _G[DUF_FRAME_DATA[unit].frame.."_RaceIcon"].Icon
	end
--	if (race == DUF_TEXT.Draenei) then --Fizzlemizz: May want to change this at some stage to something more generic rather than tagging each unit frame
	if race == "draenei" then --Fizzlemizz: May want to change this at some stage to something more generic rather than tagging each unit frame
		_G[DUF_FRAME_DATA[unit].frame].deathseq = 121
	else
		_G[DUF_FRAME_DATA[unit].frame].deathseq = 1
	end
	if (texture.targetIcon) then
		local targetIndex
		if (unit == "target" or unit == "targettarget" or unit == "focus") then
			targetIndex = GetRaidTargetIndex(unit)
		else
			targetIndex = GetRaidTargetIndex(unit.."target")
		end
		texture:SetTexCoord(0, 1, 0, 1)
		if (targetIndex) then
			SetRaidTargetIconTexture(texture, targetIndex)
			texture:Show()
		else
			texture:Hide()
		end
		return
	end
	if (toggle) then
		texture = _G[DUF_FRAME_DATA[unit].frame.."_ClassIcon"].Icon
	end
	if (not UnitName(unit)) then
--		race=DUF_TEXT.Human
--		sex=1
		race=select(2, UnitRace("player"))
		sex=UnitSex("player")
	end
	if sex == 2 then
		sex = "male"
	elseif sex == 3 then
		sex = "female"
	else
		sex = nil
	end
	texture:Show()
	if (race and sex) then
--		if race == "Scourge" then -- Until we can find the icon for them
--			race = "Undead"
--		end
--		local size = 0.129
--		if not races[race] or not races[race][sex] then 
--			print("DUF_Set.lua, RACE OR SEX NOT FOUND:", race, sex)
--			return
--		end
		race = lower(race)
		race = fixedRaceAtlasNames[race] or race
--		race = gsub(race, " ", "")
		local Atlas = "raceicon-"..race.."-"..sex
--		local x = races[race][sex][1]*size
--		local y = races[race][sex][2]*size
--		texture:SetTexture("Interface/Glues/CharacterCreate/CharacterCreateIcons")
		texture:SetAtlas(Atlas, true)
		-- Maybe replace with GetRaceAtlas("human", "female") if the funcion exists outside of GLUE
--		texture:SetTexCoord(x, x+size, y, y+size)
	elseif (UnitPlayerControlled(unit)) then
		texture:SetTexCoord(0, 1, 0, 1)
		texture:SetTexture("Interface/AddOns/DiscordUnitFrames/Icons/Sheep")
	elseif (ctype) then
		texture:SetTexCoord(0, 1, 0, 1)
		if (ctype == DUF_TEXT.Beast) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Beast")
		elseif (ctype == DUF_TEXT.Dragonkin) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Dragonkin")
		elseif (ctype == DUF_TEXT.Critter) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Critter")
		elseif (ctype == DUF_TEXT.Demon) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Demon")
		elseif (ctype == DUF_TEXT.Elemental) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Elemental")
		elseif (ctype == DUF_TEXT.Giant) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Giant")
		elseif (ctype == DUF_TEXT.Humanoid) then
			if (faction == DUF_TEXT.Horde) then
				texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Horde")
			elseif (faction == DUF_TEXT.Alliance) then
				texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Alliance")
			else
				texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Humanoid")
			end
		elseif (ctype == DUF_TEXT.NotSpecified) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\NotSpecified")
		elseif (ctype == DUF_TEXT.Summoned) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Summoned")
		elseif (ctype == DUF_TEXT.Undead) then texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Undead")
		else texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Gryphon")
		end
	else
		texture:SetTexCoord(0, 1, 0, 1)
		texture:SetTexture("Interface\\AddOns\\DiscordUnitFrames\\Icons\\Unknown")
	end
end

function NS:DUF_Set_RankIcon(unit)
	local _, rankNumber = NS.GetPVPRankInfo(NS.UnitPVPRank(unit))
	local texture = _G[DUF_FRAME_DATA[unit].frame.."_RankIcon_Texture"]
	if (texture.targetIcon) then
		local targetIndex
		if (unit == "target" or unit == "targettarget" or unit == "focus") then
			targetIndex = GetRaidTargetIndex(unit)
		else
			targetIndex = GetRaidTargetIndex(unit.."target")
		end
		if (targetIndex) then
			SetRaidTargetIconTexture(texture, targetIndex)
			texture:Show()
		else
			texture:Hide()
		end
		return
	end
	if (not UnitName(unit)) then
		rankNumber=9
	elseif (not UnitIsPlayer(unit)) then
		texture:Hide()
		return
	end
	if (rankNumber > 0) then
		texture:Show()
		texture:SetTexture(format("%s%02d","Interface\\PvPRankBadges\\PvPRank", rankNumber))
	else
		texture:Hide()
	end
end
